@@ -5,7 +5,6 @@
 import os
 import subprocess
 import sys
-import recommonmark.parser
 
 
 # -- path -------------------------------------------------------
@@ -25,9 +24,9 @@ def bash(filename):
 
 # -- source files and parsers -----------------------------------
 
-source_suffix = ['.rst', '.md', '.ipynb']
-source_parsers = {
-    '.md': recommonmark.parser.CommonMarkParser,
+source_suffix = {
+    '.rst': 'restructuredtext',
+    '.md': 'markdown',
 }
 
 
@@ -39,8 +38,9 @@ extensions = [
     'sphinx.ext.intersphinx',
     'sphinx.ext.mathjax',
     'nbsphinx',
-    'jupyter_sphinx.execute',
+    'jupyter_sphinx',
     'IPython.sphinxext.ipython_console_highlighting',
+    'recommonmark',
 ]
 
 intersphinx_mapping = {
@@ -51,6 +51,9 @@ intersphinx_mapping = {
 }
 
 nbsphinx_allow_errors = True   # exception ipstruct.py ipython_genutils
+nbsphinx_execute = 'always'
+# Disable including require.js because it is also included by jupyter_sphinx:
+nbsphinx_requirejs_path = ''
 
 # -- General information -------
 
@@ -68,7 +71,21 @@ copyright = '2017 Project Jupyter'
 author = 'Jupyter Team'
 
 language = None
-exclude_patterns = ['_build', '**.ipynb_checkpoints', 'examples/Imag*', 'examples/Index.ipynb']
+exclude_patterns = [
+    '**.ipynb_checkpoints',
+    'examples.md',
+    'examples/Beat Frequencies.ipynb',
+    'examples/Controller.ipynb',
+    'examples/Exploring Graphs.ipynb',
+    'examples/Export As (nbconvert).ipynb',
+    'examples/Factoring.ipynb',
+    'examples/Imag*',
+    'examples/Index.ipynb',
+    'examples/Lorenz Differential Equations.ipynb',
+    'examples/Media widgets.ipynb',
+    'examples/Variable Inspector.ipynb',
+    'examples/Widget Alignment.ipynb',
+]
 pygments_style = 'sphinx'
 todo_include_todos = False
 
